CustomMarker class

Constructors

CustomMarker({required String id, required LatLng position, required Widget widget, double width = 50, double height = 50, Alignment alignment = Alignment.center, int rotation = 0, String? fallbackAssetPath, String? fallbackAssetPackage})

Properties

alignment → Alignment
final
fallbackAssetPackage → String?
final
fallbackAssetPath → String?
final
hashCode → int
The hash code for this object.
no setteroverride
height → double
final
id → String
final
position → LatLng
final
rotation → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → Widget
final
width → double
final

Methods

getAnchor() → Offset
getBitmapDescriptor() → Future<BitmapDescriptor>
getUint8List() → Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override