MapBoxView class

Inheritance

Constructors

MapBoxView({Key? key, required Place initialLocation, required double initialZoom, required MapMovedCallback? onMapMoved, required bool interactive, required List<CircleMarker> circleMarkers, required MapboxSdkOptions options, required List<PolyLineLayer> polylines, required List<CustomMarker> markers, required EdgeInsets padding, required EdgeInsets buttonsPadding, required List<HeatmapConfig> heatmapConfig, required dynamic onControllerReady(MapViewController)?, required bool showMyLocation})
const

Properties

buttonsPadding → EdgeInsets
final
circleMarkers → List<CircleMarker>
final
hashCode → int
The hash code for this object.
no setterinherited
heatmapConfig → List<HeatmapConfig>
final
initialLocation → Place
final
initialZoom → double
final
interactive → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
markers → List<CustomMarker>
final
onControllerReady → dynamic Function(MapViewController)?
final
onMapMoved → MapMovedCallback?
final
options → MapboxSdkOptions
final
padding → EdgeInsets
final
polylines → List<PolyLineLayer>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMyLocation → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited