widget library

Classes

GenericMap
LatLngBounds
Data structure representing rectangular bounding box constrained by its northwest and southeast corners
MapMovedEvent

Typedefs

MapMovedCallback = void Function(MapMovedEvent event)
How the provider widgets report a raw camera event to GenericMap, and how GenericMap reports the debounced one on to the host.