isUserGesture property
bool
get
isUserGesture
Whether the user moved the map, as opposed to the app or the map itself.
Implementation
bool get isUserGesture => source == MapMoveSource.gesture;
Whether the user moved the map, as opposed to the app or the map itself.
bool get isUserGesture => source == MapMoveSource.gesture;