mapController property
- @Deprecated('Read `controller`; hand maps over with `attach`. ' 'Completing this directly throws when the platform view is recreated.')
The completer holding the map currently attached.
Read controller instead, and hand maps over with attach. Completing
this directly throws Bad state: Future already completed once the
platform view is recreated.
Implementation
@Deprecated('Read `controller`; hand maps over with `attach`. '
'Completing this directly throws when the platform view is recreated.')
Completer<MapboxMap> get mapController => _mapController;