MapMovedEvent class
Constructors
- MapMovedEvent({required LatLng latLng, String? title, String? address, required double zoom, required LatLngBounds bounds, required MapMoveEventType type, MapMoveSource source = MapMoveSource.unknown})
- MapMovedEvent.addressResolved({required LatLng latLng, required double zoom, required LatLngBounds bounds, String? title, String? address, MapMoveSource source = MapMoveSource.unknown})
-
factory
- MapMovedEvent.idle({required LatLng latLng, required double zoom, required LatLngBounds bounds, MapMoveSource source = MapMoveSource.unknown})
-
factory
- MapMovedEvent.start({required LatLng latLng, required double zoom, required LatLngBounds bounds, MapMoveSource source = MapMoveSource.unknown})
-
factory
Properties
- address → String?
-
final
- bounds → LatLngBounds
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isProgrammatic → bool
-
Whether this move came from the app's own camera call.
no setter
- isStart → bool
-
no setter
- isUserGesture → bool
-
Whether the user moved the map, as opposed to the app or the map itself.
no setter
- latLng → LatLng
-
final
- place → Place
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → MapMoveSource
-
What moved the camera.
final
- title → String?
-
final
- type ↔ MapMoveEventType
-
getter/setter pair
- zoom → double
-
final
Methods
-
copyWith(
{MapMoveEventType? type, LatLng? latLng, String? title, String? address, double? zoom, LatLngBounds? bounds, MapMoveSource? source}) → MapMovedEvent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited